Math Magik (v0.1.8)
####################
:Author:    Roie R. Black
:Email: roie.black@gmail.com
:Docs:      https://rblack42.github.io/math-magik

..  start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |github| |travis| |appveyor| |coverage|

.. |github| image:: https://github.com/rblack42/math-magik/actions/workflows/python-app.yml/badge.svg
    :alt: Github Workflows
    :target: https://github.com/rblack42/math-magik

.. |travis| image:: https://travis-ci.com/rblack42/math-magik.svg?branch=main
    :alt: Travis-CI Build Status
    :target: https://travis-ci.com/rblack42/math-magik

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/pevivsa6n5adw5lw?svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/rblack42/math-magik


.. |coverage| image:: https://coveralls.io/repos/github/rblack42/math-magik/badge.svg?branch=main
    :target: https://coveralls.io/github/rblack42/math-magik?branch=main
    :alt: Code Coverage"

..  image:: rst/_static/lpp.gif
    :align: center
    :width: 600

.. end-badges

This project uses *OpenSCAD* and a few supporting libraries to generate 3D models
of free-flight model airplanes. The accompanying Python software assists
in creating a design and performs analysis on the design to produce an estimate
of the weight and center of gravity of the design. This project is the subject
of an article in the 2021 edition of the National Free Flight Society
Symposium.

The project documentation is available at the link above. There you will find
material detailing the Python code developed to support this project, and
information on how *OpenSCAD* can be used to build 3D models of proposed designs.
The primary focus of this documentation is the design of a Limited Pennyplane
indoor model, but other designs will be included here as well.

If you are interested in assisting with the development of this project, or
need help with anything found here, please contact me by email. I welcome
questions and ideas for extending this project.





